# -*- coding: utf-8 -*-

"""Console script for thanks."""

import click
from .thanks import find_package_roles


@click.command()
@click.argument('requirements', default='requirements.txt', type=click.Path(exists=True))
def main(requirements):
    """Console script for thanks."""
    find_package_roles(requirements)
    return 0


if __name__ == "__main__":
    import sys
    sys.exit(main())



# -*- coding: utf-8 -*-

import json
import os
import pprint
import requirements
from termcolor import colored
try:
    import xmlrpclib
except ImportError:
    import xmlrpc.client as xmlrpclib


json_file = ("{}/thanks.json".format(os.path.dirname(os.path.realpath(__file__))))
client = xmlrpclib.ServerProxy('https://pypi.python.org/pypi')


def find_package_roles(requirements_file):
    data = {}
    give_thanks_to = {}
    with open(json_file, 'r') as j:
        print("Loading data about contributors...")
        data = json.load(j)
    with open(requirements_file, 'r') as reqs:
        print("Scanning your requirements file...")
        for req in requirements.parse(reqs):
            roles = client.package_roles(req.name)
            role_names = set(role[1] for role in roles)
            for name in role_names:
                if name in give_thanks_to:
                    give_thanks_to[name]['packages'].append(req.name)
                else:
                    if name in data:
                        give_thanks_to[name] = {'url': data[name], 'packages': [req.name]}
        if give_thanks_to:
            print("Found the following contributors to support: \n")
            for contributor in give_thanks_to:
                print(
                    "{} contributes to {}, support them at {}".format(
                        colored(contributor, 'blue'),
                        colored(",".join(give_thanks_to[contributor]['packages']), 'red'),
                        colored(give_thanks_to[contributor]['url'], 'green'),
                    ),
                )
            print("\n")



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'Click>=6.0',
    'requirements-parser==0.2.0',
    'termcolor==1.1.0',
]

setup_requirements = [
    # TODO(phildini): Put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    # TODO: Put package test requirements here
]

setup(
    name='thanks',
    version='0.0.3',
    description="Finding ways to fund the packages you use.",
    long_description=readme + '\n\n' + history,
    author="Philip James",
    author_email='phildini@phildini.net',
    url='https://github.com/phildini/thanks',
    packages=find_packages(include=['thanks']),
    entry_points={
        'console_scripts': [
            'thanks=thanks.cli:main',
        ],
    },
    include_package_data=True,
    install_requires=requirements,
    license="Apache Software License 2.0",
    zip_safe=False,
    keywords='thanks',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
